==> goTools_1.24.0.zip: goTools/doc/goTools.R <==
###################################################
### chunk number 1: 
###################################################
#line 82 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpsX5eJB/R.INSTALL12f549e7/goTools/inst/doc/goTools.Rnw"
library("goTools", verbose=FALSE)
data(probeID)  


###################################################
### chunk number 2: 
###################################################
#line 91 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpsX5eJB/R.INSTALL12f549e7/goTools/inst/doc/goTools.Rnw"
class(affylist)
length(affylist)
affylist[[1]][1:5]


###################################################
### chunk number 3:  eval=FALSE
###################################################
## #line 141 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpsX5eJB/R.INSTALL12f549e7/goTools/inst/doc/goTools.Rnw"
## library(GO.db)
## subset=c(L1=list(affylist[[1]][1:5]),L2=list(affylist[[2]][1:5]))
## res <-ontoCompare(subset, probeType="hgu133a")


###################################################
### chunk number 4: ontoPlotEg1 eval=FALSE
###################################################
## #line 179 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpsX5eJB/R.INSTALL12f549e7/goTools/inst/doc/goTools.Rnw"
## library(GO.db)
## subset=c(L1=list(affylist[[1]][1:5]),L2=list(affylist[[2]][1:5]))
## res <- ontoCompare(subset, probeType="hgu133a", plot=TRUE)


###################################################
### chunk number 5: 
###################################################
#line 195 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpsX5eJB/R.INSTALL12f549e7/goTools/inst/doc/goTools.Rnw"
EndNodeList()


###################################################
### chunk number 6:  eval=FALSE
###################################################
## #line 208 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpsX5eJB/R.INSTALL12f549e7/goTools/inst/doc/goTools.Rnw"
## MFendnode <- CustomEndNodeList("GO:0003674", rank=2)


###################################################
### chunk number 7:  eval=FALSE
###################################################
## #line 217 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpsX5eJB/R.INSTALL12f549e7/goTools/inst/doc/goTools.Rnw"
## res <- ontoCompare(subset, probeType="hgu133a", endnode=MFendnode, goType="MF")

==> goTools_1.26.0.zip: goTools/doc/goTools.R <==
###################################################
### chunk number 1: 
###################################################
#line 82 "goTools.Rnw"
library("goTools", verbose=FALSE)
data(probeID)  


###################################################
### chunk number 2: 
###################################################
#line 91 "goTools.Rnw"
class(affylist)
length(affylist)
affylist[[1]][1:5]


###################################################
### chunk number 3:  eval=FALSE
###################################################
## #line 141 "goTools.Rnw"
## library(GO.db)
## subset=c(L1=list(affylist[[1]][1:5]),L2=list(affylist[[2]][1:5]))
## res <-ontoCompare(subset, probeType="hgu133a")


###################################################
### chunk number 4: ontoPlotEg1 eval=FALSE
###################################################
## #line 179 "goTools.Rnw"
## library(GO.db)
## subset=c(L1=list(affylist[[1]][1:5]),L2=list(affylist[[2]][1:5]))
## res <- ontoCompare(subset, probeType="hgu133a", plot=TRUE)


###################################################
### chunk number 5: 
###################################################
#line 195 "goTools.Rnw"
EndNodeList()


###################################################
### chunk number 6:  eval=FALSE
###################################################
## #line 208 "goTools.Rnw"
## MFendnode <- CustomEndNodeList("GO:0003674", rank=2)


###################################################
### chunk number 7:  eval=FALSE
###################################################
## #line 217 "goTools.Rnw"
## res <- ontoCompare(subset, probeType="hgu133a", endnode=MFendnode, goType="MF")
